@@ -8,11 +8,10 @@ use std::sync::mpsc::Sender;
 const EXCHANGE_NAME: &str = "bitget";
 
 #[allow(clippy::unnecessary_unwrap)]
-pub(crate) fn crawl_funding_rate(
+pub(crate) async fn crawl_funding_rate(
     market_type: MarketType,
     symbols: Option<&[String]>,
     tx: Sender<Message>,
-    duration: Option<u64>,
 ) {
     let tx = create_conversion_thread(
         EXCHANGE_NAME.to_string(),
@@ -22,7 +21,7 @@ pub(crate) fn crawl_funding_rate(
     );
 
     let symbols: Vec<String> = if symbols.is_none() || symbols.unwrap().is_empty() {
-        fetch_symbols_retry(EXCHANGE_NAME, market_type)
+        tokio::task::block_in_place(move || fetch_symbols_retry(EXCHANGE_NAME, market_type))
     } else {
         symbols
             .unwrap()
@@ -30,16 +29,17 @@ pub(crate) fn crawl_funding_rate(
             .map(|symbol| symbol.to_string())
             .collect()
     };
-    let channels: Vec<String> = symbols
+    let topics: Vec<(String, String)> = symbols
         .into_iter()
-        .map(|symbol| format!("swap/funding_rate:{}", symbol))
+        .map(|symbol| ("funding_rate".to_string(), symbol))
         .collect();
 
     match market_type {
         MarketType::InverseSwap | MarketType::LinearSwap => {
-            let ws_client = BitgetSwapWSClient::new(tx, None);
-            ws_client.subscribe(&channels);
-            ws_client.run(duration);
+            let ws_client = BitgetSwapWSClient::new(tx, None).await;
+            ws_client.subscribe(&topics).await;
+            ws_client.run().await;
+            ws_client.close();
         }
         _ => panic!("Bitget {} does NOT have funding rates", market_type),
     }
