@@ -10,6 +10,14 @@ use utils::parse;
 
 const EXCHANGE_NAME: &str = "bybit";
 
+#[test_case(MarketType::InverseFuture)]
+#[test_case(MarketType::InverseSwap)]
+#[test_case(MarketType::LinearSwap)]
+#[tokio::test(flavor = "multi_thread", worker_threads = 8)]
+async fn test_crawl_trade_all(market_type: MarketType) {
+    test_all_symbols!(crawl_trade, EXCHANGE_NAME, market_type, MessageType::Trade)
+}
+
 #[test_case(MarketType::InverseFuture, "BTCUSDM22")]
 #[test_case(MarketType::InverseSwap, "BTCUSD")]
 #[test_case(MarketType::LinearSwap, "BTCUSDT")]
@@ -80,7 +88,7 @@ async fn test_crawl_ticker(market_type: MarketType, symbol: &str) {
 #[test_case(MarketType::InverseFuture)]
 #[test_case(MarketType::InverseSwap)]
 #[test_case(MarketType::LinearSwap)]
-#[tokio::test(flavor = "multi_thread")]
+#[tokio::test(flavor = "multi_thread", worker_threads = 8)]
 async fn test_crawl_candlestick(market_type: MarketType) {
     gen_test_crawl_candlestick!(EXCHANGE_NAME, market_type)
 }
